@@ -18,17 +18,22 @@ public:
   PyObject *widget;
   void     *type;
   PyObject *link;
+  char     type_name[64];
   CallbackStruct( PyObject *theFunc, PyObject *theData, PyObject *theWidget, PyObject *theLink = 0):
     func(theFunc),
     data(theData),
     widget(theWidget)
-  {}
+  {
+    memset(type_name, 0, 64);
+  }
   CallbackStruct( PyObject *theFunc, PyObject *theData, void *theType):
     func(theFunc),
     data(theData),
     widget(0),
     type(theType)
-  {}
+  {
+    memset(type_name, 0, 64);
+  }
   
 };
 
